multidim.models.CDER.gausscoords — GDA Toolbox v1.0 Manual

# multidim.models.CDER.gausscoords

`CDER.` `gausscoords`(parsimonious=True)

  This is the Gaussian-building heart of the CDER algorithm. Look to elders, and look to successor. How does entropy change? If the entropy is a local minimum, then build a Gaussian coordinate with the dominant label. This populates `self.gaussians` for a `CDER` object.

  Generally, a user will never call this. It is called by `fit()`

  Parameters: | parsimonious: bool If True, then ignore unlikely regions quickly, to minimize the number of Gaussian coordinates. If False, then check all levels of the CoverTree. (default: True)

  See also

  `build_gaussians()`
    func:`fit`

#### Previous topic

multidim.models.CDER.fit

#### Next topic

multidim.models.CDER.get_params